package cn.com.tenlion.configcontent.service.contentantistop.impl;

import cn.com.tenlion.configcontent.dao.contentantistop.IContentAntistopDao;
import cn.com.tenlion.configcontent.pojo.dtos.contentantistop.ContentAntistopDTO;
import cn.com.tenlion.configcontent.pojo.dtos.contentantistop.ContentAntistopExcel;
import cn.com.tenlion.configcontent.pojo.dtos.contentantistop.ContentAntistopExcelListener;
import cn.com.tenlion.configcontent.pojo.vos.contentantistop.ContentAntistopVO;
import cn.com.tenlion.configcontent.service.contentantistop.IContentAntistopService;
import cn.com.tenlion.configcontent.util.AntistopUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.fastjson.JSONArray;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import ink.wgink.common.base.DefaultBaseService;
import ink.wgink.exceptions.RemoveException;
import ink.wgink.exceptions.SearchException;
import ink.wgink.pojo.ListPage;
import ink.wgink.pojo.result.SuccessResult;
import ink.wgink.pojo.result.SuccessResultList;
import ink.wgink.util.UUIDUtil;
import ink.wgink.util.map.HashMapUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.io.File;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * @ClassName: ContentAntistopServiceImpl
 * @Description: 内容评论敏感词库
 * @Author: WenG
 * @Date: 2020-05-08 23:30
 * @Version: 1.0
 **/
@Service
public class ContentAntistopServiceImpl extends DefaultBaseService implements IContentAntistopService {

    @Autowired
    private IContentAntistopDao contentAntistopDao;

    @Override
    public SuccessResult saveContentAntistop(ContentAntistopVO contentAntistopVO) throws Exception {
        saveContentAntistopInfo(null, contentAntistopVO);
        return new SuccessResult();
    }

    @Override
    public SuccessResult saveContentAntistopByToken(String token, ContentAntistopVO contentAntistopVO) throws Exception {
        saveContentAntistopInfo(token, contentAntistopVO);
        return new SuccessResult();
    }

    /**
     * 新增内容评论敏感词库
     *
     * @param token
     * @param contentAntistopVO
     * @throws Exception
     */
    private void saveContentAntistopInfo(String token, ContentAntistopVO contentAntistopVO) throws Exception {
        if(contentAntistopVO.getContentAntistopName() == null) {
            return;
        }
        contentAntistopVO.setContentAntistopName(contentAntistopVO.getContentAntistopName().trim());
        Map<String, Object> params = HashMapUtil.beanToMap(contentAntistopVO);
        String contentAntistopId = UUIDUtil.getUUID();
        params.put("contentAntistopId", contentAntistopId);
        if (StringUtils.isBlank(token)) {
            setSaveInfo(params);
        } else {
            setAppSaveInfo(token, params);
        }
        ContentAntistopDTO contentAntistopDTO = getContentAntistopByName(contentAntistopVO.getContentAntistopName());
        if(contentAntistopDTO == null) {
            contentAntistopDao.saveContentAntistop(params);
            AntistopUtil.push(contentAntistopId, contentAntistopVO.getContentAntistopName());
        }
    }

    @Override
    public SuccessResult removeContentAntistop(String ids) throws RemoveException {
        removeContentAntistopInfo(null, ids);
        return new SuccessResult();
    }

    @Override
    public SuccessResult removeContentAntistopByToken(String token, String ids) throws RemoveException {
        removeContentAntistopInfo(token, ids);
        return new SuccessResult();
    }

    /**
     * 删除内容评论敏感词库
     *
     * @param token
     * @param ids
     */
    private void removeContentAntistopInfo(String token, String ids) {
        Map<String, Object> params = getHashMap(3);
        List<String> list = Arrays.asList(ids.split("_"));
        params.put("contentAntistopIds", list);
        if (StringUtils.isBlank(token)) {
            setUpdateInfo(params);
        } else {
            setAppUpdateInfo(token, params);
        }
        for (String id : list) {
            AntistopUtil.deleteAntistop(id);
        }
        contentAntistopDao.removeContentAntistop(params);
    }

    @Override
    public SuccessResult updateContentAntistop(String contentAntistopId, ContentAntistopVO contentAntistopVO) throws Exception {
        updateContentAntistopInfo(null, contentAntistopId, contentAntistopVO);
        return new SuccessResult();
    }

    @Override
    public SuccessResult updateContentAntistopByToken(String token, String contentAntistopId, ContentAntistopVO contentAntistopVO) throws Exception {
        updateContentAntistopInfo(token, contentAntistopId, contentAntistopVO);
        return new SuccessResult();
    }

    /**
     * 修改内容评论敏感词库
     *
     * @param token
     * @param contentAntistopId
     * @param contentAntistopVO
     */
    private void updateContentAntistopInfo(String token, String contentAntistopId, ContentAntistopVO contentAntistopVO) throws Exception {
        Map<String, Object> params = HashMapUtil.beanToMap(contentAntistopVO);
        params.put("contentAntistopId", contentAntistopId);
        if (StringUtils.isBlank(token)) {
            setUpdateInfo(params);
        } else {
            setAppUpdateInfo(token, params);
        }
        contentAntistopDao.updateContentAntistop(params);
        AntistopUtil.push(contentAntistopId, contentAntistopVO.getContentAntistopName());
    }

    @Override
    public ContentAntistopDTO getContentAntistopById(String contentAntistopId) throws SearchException {
        Map<String, Object> params = super.getHashMap(1);
        params.put("contentAntistopId", contentAntistopId);
        return contentAntistopDao.getContentAntistop(params);
    }

    @Override
    public ContentAntistopDTO getContentAntistopByName(String antistopName) throws SearchException {
        Map<String, Object> params = super.getHashMap(1);
        params.put("antistopName", antistopName);
        return contentAntistopDao.getContentAntistopByName(params);
    }

    @Override
    public List<ContentAntistopDTO> listContentAntistop(Map<String, Object> params) throws SearchException {
        return contentAntistopDao.listContentAntistop(params);
    }

    @Override
    public SuccessResultList<List<ContentAntistopDTO>> listPageContentAntistop(ListPage page) throws SearchException {
        PageHelper.startPage(page.getPage(), page.getRows());
        List<ContentAntistopDTO> contentAntistopDTOs = contentAntistopDao.listContentAntistop(page.getParams());
        PageInfo<ContentAntistopDTO> pageInfo = new PageInfo<>(contentAntistopDTOs);
        return new SuccessResultList<>(contentAntistopDTOs, pageInfo.getPageNum(), pageInfo.getTotal());
    }

    @Override
    public SuccessResult saveContentAntistopExcel(String saveFilePath) throws Exception {
        File areaDataFile = new File(saveFilePath);
        JSONArray excelDataJsonArray = new JSONArray();
        EasyExcel.read(areaDataFile, ContentAntistopExcel.class, new ContentAntistopExcelListener() {
            @Override
            public void listAreaExcel(List<ContentAntistopExcel> contentAntistopExcels) throws Exception {
                for (ContentAntistopExcel areaExcel : contentAntistopExcels) {
                    if(!StringUtils.isEmpty(areaExcel.getName())) {
                        ContentAntistopVO vo = new ContentAntistopVO();
                        vo.setContentAntistopType(areaExcel.getType() == null ? "2" : "1".equals(areaExcel.getType()) ? "1" : "2");
                        vo.setContentAntistopName(areaExcel.getName().trim());
                        /**
                         * 判断该name是否已经存在
                         */
                        saveContentAntistop(vo);
                    }
                }
            }
        }).sheet().doRead();
        return new SuccessResult();
    }

}
